# DSSAT with Language Models


## PRE-REQUISITES

This project requires that you set the following API keys:

* GROQ_API_KEY
* OPENAI_API_KEY
* WANDB_API_KEY


## INSTALL:
```
pip install dssatlm
```

## OBJECTIVES
[TO-DO]

## LIMITATIONS
[TO-DO]

## FUTURE PLANS
[TO-DO]

## ACKNOWLEDGEMENT
[TO-DO]


